summaryrefslogtreecommitdiffstats
path: root/searchlib
diff options
context:
space:
mode:
authorTor Egge <Tor.Egge@oath.com>2018-04-06 11:31:57 +0000
committerTor Egge <Tor.Egge@oath.com>2018-04-06 11:35:19 +0000
commit58ef78213b8c087eb4398c126586c97ab611f2f4 (patch)
treebd975f61563b1b37752f86babf8597682faa2fe1 /searchlib
parent74a9445225824c331438990edd1c4cda108d8d80 (diff)
Use active lids bitvector for whitelisting.
This replaces nested small numeric attribute vector for blaclisting.
Diffstat (limited to 'searchlib')
-rw-r--r--searchlib/src/vespa/searchlib/common/idocumentmetastore.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/searchlib/src/vespa/searchlib/common/idocumentmetastore.h b/searchlib/src/vespa/searchlib/common/idocumentmetastore.h
index 2187c3f96a7..6fc8b9f43b5 100644
--- a/searchlib/src/vespa/searchlib/common/idocumentmetastore.h
+++ b/searchlib/src/vespa/searchlib/common/idocumentmetastore.h
@@ -143,10 +143,10 @@ struct IDocumentMetaStore {
virtual LidUsageStats getLidUsageStats() const = 0;
/**
* Creates a black list blueprint that returns a search iterator
* that gives hits for all documents that should not be visible.
**/
- virtual std::unique_ptr<queryeval::Blueprint> createBlackListBlueprint() const = 0;
+ virtual std::unique_ptr<queryeval::Blueprint> createWhiteListBlueprint() const = 0;
/**
* Give read access to the current generation of the metastore.
@@ -143,10 +143,10 @@ struct IDocumentMetaStore {
virtual LidUsageStats getLidUsageStats() const = 0;
/**
- * Creates a black list blueprint that returns a search iterator
- * that gives hits for all documents that should not be visible.
+ * Creates a white list blueprint that returns a search iterator
+ * that gives hits for all documents that should be visible.
**/